/********************************** (C) COPYRIGHT *******************************
 * File Name          : composite_km_desc.h
 * Author             : WCH
 * Version            : V1.0.0
 * Date               : 2022/08/18
 * Description        : All descriptors for the keyboard and mouse composite device.
 *********************************************************************************
 * Copyright (c) 2021 Nanjing Qinheng Microelectronics Co., Ltd.
 * Attention: This software (modified or not) and binary are used for 
 * microcontroller manufactured by Nanjing Qinheng Microelectronics.
 *******************************************************************************/

/*******************************************************************************/
/* Header File */
#include "usbd_desc.h"

/*******************************************************************************/
/* Device Descriptor */
const uint8_t MyDevDescr[] = { 0x12,                                  // bLength
        0x01,                                                 // bDescriptorType
        0x00, 0x02,                                             // bcdUSB
        0x00,                                                   // bDeviceClass
        0x00,                                                 // bDeviceSubClass
        0x02,                                                 // bDeviceProtocol
        DEF_USBD_UEP0_SIZE,                                   // bMaxPacketSize0
        (uint8_t) DEF_USB_VID, (uint8_t) ( DEF_USB_VID >> 8),    // idVendor
        (uint8_t) DEF_USB_PID, (uint8_t) ( DEF_USB_PID >> 8),    // idProduct
        0x00, DEF_IC_PRG_VER,                                   // bcdDevice
        0x01,                                                   // iManufacturer
        0x02,                                                   // iProduct
        0x03,                                                   // iSerialNumber
        0x01,                                             // bNumConfigurations
        };

/* Configuration Descriptor Set */
const uint8_t MyCfgDescr[] = {
/* Configuration Descriptor */
0x09,                                                   // bLength
        0x02,                                                 // bDescriptorType
        0x29, 0x00,                                             // wTotalLength
        0x01,                                                  // bNumInterfaces
        0x01,                                             // bConfigurationValue
        0x00,                                                  // iConfiguration
        0x80,                        // bmAttributes: Bus Powered; Remote Wakeup
        0xFA,                                                 // MaxPower: 100mA

        /* Interface Descriptor (Joystick) */
        0x09,                                                   // bLength
        0x04,                                                 // bDescriptorType
        0x00,                                                // bInterfaceNumber
        0x00,                                               // bAlternateSetting
        0x02,                                                   // bNumEndpoints
        0x03,                                                 // bInterfaceClass
        0x00,                                              // bInterfaceSubClass
        0x00,                                    // bInterfaceProtocol: Keyboard
        0x00,                                                   // iInterface

        /* HID Descriptor (Joystick) */
        0x09,                                                   // bLength
        0x21,                                                 // bDescriptorType
        0x11, 0x01,                                             // bcdHID
        0x00,                                                   // bCountryCode
        0x01,                                                 // bNumDescriptors
        0x22,                                                 // bDescriptorType
        0x44, 0x00,                                         // wDescriptorLength

        /* Endpoint Descriptor (Keyboard) */
        0x07,                                                   // bLength
        0x05,                                                 // bDescriptorType
        0x02,                                 // bEndpointAddress: IN Endpoint 1
        0x03,                                                   // bmAttributes
        0x40, 0x00,                                            // wMaxPacketSize
        0x0A,                                                 // bInterval: 10mS

        /* Endpoint Descriptor (Keyboard) */
        0x07,                                                   // bLength
        0x05,                                                 // bDescriptorType
        0x81,                                 // bEndpointAddress: IN Endpoint 1
        0x03,                                                   // bmAttributes
        0x40, 0x00,                                            // wMaxPacketSize
        0x0A,                                                // bInterval: 10mS

        };

/* Keyboard Report Descriptor */
const uint8_t JoystickRepDesc[] = {
        0x05, 0x01,                                  // Usage Page (Generic Desktop)
        0x09, 0x04,                                  // Usage (Joystick)
        0xA1, 0x01,                                  // Collection (Application)
        0x05, 0x01,                                  // Usage Page (Generic Desktop)
        0x09, 0x01,                                  // Usage (Pointer)
        0xA1, 0x02,                                  // Collection (Logical)
        0x09, 0x30,                                  // Usage (X)
        0x09, 0x31,                                  // Usage (Y)
        0x09, 0x32,                                  // Usage (Z)
        0x09, 0x33,                                  // Usage (Rx)
        0x09, 0x34,                                  // Usage (Ry)
        0x09, 0x35,                                  // Usage (Rz)
        0x09, 0x36,                                  // Usage (Slider)
        0x09, 0x37,                                  // Usage (Dial)
        0x15, 0x00,                                  // Logical Minimum (0)
        0x26, 0xFF, 0x03,                            // Logical Maximum (1023)
        0x75, 0x10,                                  // Report Size (16)
        0x95, 0x08,                                  // Report Count (8)
        0x81, 0x02,                                  // Input (Data,Variable,Absolute)
        0x05, 0x09,                                  // Usage Page (Button)
        0x19, 0x01,                                  // Usage Minimum (Button 1)
        0x29, 0x20,                                  // Usage Minimum (Button 32)
        0x15, 0x00,                                  // Logical Minimum (0)
        0x25, 0x01,                                  // Logical Maximum (1)
        0x75, 0x01,                                  // Report Size (1)
        0x95, 0x20,                                  // Report Count (32)
        0x81, 0x02,                                  // Input (Data,Variable,Absolute)
        0xC0,                                        // End Collection
        0xA1, 0x02,                                  // Collection (Logical)
        0x95, 0x07,                                  // Report Count (7)
        0x75, 0x08,                                  // Report Size (8)
        0x09, 0x01,                                  // Usage (Button 1)
        0x91, 0x02,                                  // Output (Data,Variable,Absolute)
        0xC0,                                        // End Collection
        0xC0                                         // End Collection
        };

/* Qualifier Descriptor */
const uint8_t MyQuaDesc[] = { 0x0A,                                   // bLength
        0x06,                                                 // bDescriptorType
        0x00, 0x02,                                             // bcdUSB
        0x00,                                                   // bDeviceClass
        0x00,                                                 // bDeviceSubClass
        0x00,                                                 // bDeviceProtocol
        0x40,                                                 // bMaxPacketSize0
        0x00,                                              // bNumConfigurations
        0x00                                                    // bReserved
        };

/* Language Descriptor */
const uint8_t MyLangDescr[] = { 0x04, 0x03, 0x09, 0x04 };

/* Manufacturer Descriptor */
const uint8_t MyManuInfo[] = { 0x0E, 0x03, 0x54, 0x00, 0x79, 0x00, 0x61, 0x00,
        0x6E, 0x00, 0x2D, 0x00, 0x48, 0x00 };

/* Product Information */
const uint8_t MyProdInfo[] = { 0x20, 0x03, 0x54, 0x00, 0x79, 0x00, 0x61, 0x00,
        0x6E, 0x00, 0x2D, 0x00, 0x48, 0x00, 0x20, 0x00, 0x4A, 0x00, 0x6F, 0x00,
        0x79, 0x00, 0x73, 0x00, 0x74, 0x00, 0x69, 0x00, 0x63, 0x00, 0x6B, 0x00 };

/* Serial Number Information */
const uint8_t MySerNumInfo[] = { 0x16, 0x03, '0', 0, '1', 0, '2', 0, '3', 0,
        '4', 0, '5', 0, '6', 0, '7', 0, '8', 0, '9', 0 };
